@@ -9,12 +9,18 @@ from .did_url import DIDUrl
 from .resource import Resource
 
 
+class ServiceEndpoint(Resource):
+    """List of Service Endpoints"""
+
+    uri: Union[DIDUrl, AnyUrl]
+
+
 class Service(Resource):
     """Representation of DID Document Services."""
 
     id: DIDUrl
     type: str
-    service_endpoint: Union[DIDUrl, AnyUrl, Literal[""]]
+    service_endpoint: Union[DIDUrl, AnyUrl, Literal[""], List[ServiceEndpoint]]
 
 
 class DIDCommService(Service):
